<?php 
/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.programmation-facile.com/
  Portions created by the Initial Developer are Copyright (C) 2013
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */
 
/**
 * @file Debugger.class.php
 * @desc Cette classe permet d'effectuer du debug dans un fichier de log notamment avec AMFPHP.
 * 
 * @author Matthieu
 *
 *
 * @version 0.1 
 */

 
 /**
 * @details : 
 *		- si l'url du fichier de debug n'est pas precisee, celui ci se cree dans le meme repertoire que le fichier php qui instancie la classe Debugger.
 *
 *
 * @usage :
 *		- Debugger::GetInstance()->init("fichier_log.txt", NULL, false); ou Debugger::GetInstance()->init("fichier_log.txt"); // initialisation de la classe
 * 		- Debugger::GetInstance()->addlog("message de test"); // ajouter un message dans le fichier
 *		- Debugger::GetInstance()->clearlog(); // efface le contenu du fichier
 *		- Debugger::GetInstance()->output(); // afficher le contenu du fichier dans la fenetre courante
 *
 */
class Debugger 
{
	
	/* constantes */
	private static $o_instance = NULL; // instance unique de reference e la classe
	
	
	/* configuration du fichier de sortie */
	private $s_fileLocation; // url complete du fichier de log
	private $b_newFile; // booleen creation d'un nouveau fichier de log ou si = false continuer l'ecriture de l'ancien fichier.
	private $s_newLog = "\n--------------------------------- NOUVEAU LOG ---------------------------------\n"; // e chaque initialisation du fichier, creation d'une ligne de separation
	
	
	// ---------------------------------- __construct() ----------------------------------------------------------
   /**
	* @brief Constructeur de la classe. vide pour l'instant.
	* @param -
	*/
	private function __construct()
	{
	
		self::$o_instance = $this;		// Sert pour la methode static GetInstance()
		
	}

	// -----------------------------------------------------------------------------------------------------------
	// -------------------------------------- Methodes publiques  ------------------------------------------------
	// -----------------------------------------------------------------------------------------------------------
	
	
	// ---------------------------------- init() ----------------------------------------------------------
 	/**
	* @brief Initialisation de la classe.
	* 
	* @param (string) le nom du fichier de log.
	* @param (string) l'url du fichier de log (optionnel).
	* @param (booleen) creation d'un nouveau fichier true->oui, efface le fichier de meme nom si present (optionnel).
	*/
	public function init($s_fileName, $s_fileUrl="", $b_newF=true)
	{
		$this->s_fileLocation = $s_fileUrl.$s_fileName;
		$this->b_newFile = $b_newF;
		
		$this->addlog($this->s_newLog);
	}

	
	// ---------------------------------- addlog() ----------------------------------------------------------
 	/**
	* @brief Ajoute un message dans le fichier de log.
	* 
	* @param (string) le message a ajouter.
	* @return - 
	*/
	public function addlog($s_message)
	{
		// si on doit creer un nouveau ficheir
		if( $this->b_newFile ) $s_param = "w+";// place le pointeur de fichier au debut du fichier et reduit la taille du fichier a 0. Si le fichier n'existe pas, on tente de le creer.
		else  $s_param = "a+b";// ouvre le fichier, le curseur se place la fin pour continuer l'ecriture, creation si il n'existe pas, ecriture des donnees en mode binaire
		
		$handle = fopen($this->s_fileLocation, $s_param); 
		$i_nb_octet = fwrite($handle, $s_message."\n"); // ecriture dans le fichier
		
		if( $i_nb_octet===FALSE )
		{
			echo "impossible d'ecrire dans le fichier.";
			exit;
		}

		// sinon ecriture reussi, on ferme le fichier
		fclose($handle);
		return;
	
	}


	// ---------------------------------- clearlog() ----------------------------------------------------------
 	/**
	* @brief Efface le contenu du fichier de log.
	* 
	* @param -
	* @return - 
	*/
	public function clearlog()
	{
		$s_message = "--------------- New Log--------------------";
		$handle = fopen($this->s_fileLocation, "w+"); 
		$i_nb_octet = fwrite($handle, $s_message."\n"); // ecriture dans le fichier
		
		if( $i_nb_octet===FALSE )
		{
			echo "impossible d'ecrire dans le fichier.";
			exit;
		}
		
		// sinon ecriture reussi, on ferme le fichier
		fclose($handle);
		return;
	}
	


	// ---------------------------------- output() ----------------------------------------------------------
 	/**
	* @brief Effectue un echo de tous le contenu du fichier de log
	* 
	* @param - 
	* @return - 
	*/
	public function output()
	{
		if( file_exists($this->s_fileLocation) )
		{ 
			// affiche dans une zone textarea html
			$file = fopen($this->s_fileLocation,'r');
			?>
			<input type="hidden" id="purge" name="purge" value="purge" />
			<textarea name="infos" id="infos" rows="15" cols="150" class="menu"><?php while (!feof($file)){$donnees = fgets($file,255);echo $donnees ;} ?>
			</textarea>
			<?php 
		} 
	}
	
		
	
	// ---------------------------------- GetInstance() ----------------------------------------------------------
	/**
	* @return (Debugger) Renvoie l'instance (unique) du Debugger 
	*/
	public static function GetInstance() 
	{
		if ( self::$o_instance == NULL ) self::$o_instance = new Debugger();
		
		return self::$o_instance;
	}


	
 	// -------------------------------------------------------------------------------------------------
	// ---------------------------------------- Divers  ------------------------------------------------
	// -------------------------------------------------------------------------------------------------

	
 	/**
	* @brief Destructeur de la classe
	* Utilise pour enregistrer des messages pour le debogage, fermer les fichier ouverts en ecriture ou en lecture, realiser des operations
	* de nettoyage des objets utilises...
	*
	* @param 
	* @return 
	*/
	public function __destruct() 
	{
 
 	}



	/**
	 * @brief Determine comment la classe doit reagir lorsqu'elle est convertie en chaene de caracteres.
	 * 
	 * @usage   echo(myObject) ou print(myObject)
	 * @return  la representation de l'objet sous forme de chaene.
	 */	
	public function __toString() 
	{
		
		$s_classContent = "[Object ".__CLASS__."]<br />";
		// parcours toutes les proprietes de la classe et les renvoie	
		foreach($this as $prop => $value) 
		{
		 	$s_classContent .= "$prop => $value <br />";
		}
		 
		return $s_classContent;
   	}

}

?>